import React from 'react';
import { useHistory } from 'react-router-dom';
import { Card, Row, Col, Tab, Nav } from 'react-bootstrap';
import { formatDateTime } from '../../constans';


const TraceCode = () => {
  const history = useHistory();
  let state = { ...history.location.state };
  const product = state.product;
  return (
    <Card className="px-0 px-md-4 py-0 border-0" key={product.product_id}>
      <Card.Header>
        <div className="text-center">
          <img className="mb-3" src={window.location.origin + product.image} alt="product" />
          <div className="h4 font-weight-bold mb-3">{product.name}</div>
          <div className="mb-3">Mã sản phẩm <span className="font-weight-bold">{product.trace_code}</span></div>
          <div className="mb-3">Xuất xứ <span className="font-weight-bold">{product.origin}</span></div>
          <div className="h5 mb-3" style={{ color: '#33CC66' }}>Giá: {product.cost}</div>
        </div>
      </Card.Header>
      <Card.Body>
        <div className="main-container">
          <div className="wrapper-search py-4">
            <Tab.Container defaultActiveKey="general-information">
              <Row>
                <Col xs={12}>
                  <Nav className="nav-tabs">
                    <Nav.Item>
                      <Nav.Link eventKey="general-information" className="mb-sm-3 mb-md-0">
                        Thông tin chung
                      </Nav.Link>
                    </Nav.Item>
                    <Nav.Item>
                      <Nav.Link eventKey="product-chain-diary" className="mb-sm-3 mb-md-0">
                        Nhật kí chuỗi
                      </Nav.Link>
                    </Nav.Item>
                    <Nav.Item>
                      <Nav.Link eventKey="product-certification" className="mb-sm-3 mb-md-0">
                        Chứng nhận
                      </Nav.Link>
                    </Nav.Item>
                  </Nav>
                </Col>
                <Col xs={12}>
                  <Tab.Content>
                    <Tab.Pane eventKey="general-information">
                      <div className="mt-3 mb-3">
                        <div className="h5">Mô tả</div>
                        <div>{product.description}</div>
                      </div>
                      <div className="mb-3">
                        <div className="h5">Điều kiện nuôi trồng</div>
                        <div>{product.growing_conditions}</div>
                      </div>
                    </Tab.Pane>
                    <Tab.Pane eventKey="product-chain-diary">
                      {product.product_chain_diary.map(diary => (
                        <div>
                          <div className="h6 mt-3">{diary.company}</div>
                          <Row className="mb-3">
                            <Col>{formatDateTime(diary.date)}</Col>
                            <Col>{diary.description}</Col>
                            <Col></Col>
                            <Col></Col>
                            <Col></Col>
                            <Col></Col>
                          </Row>
                        </div>
                      ))}
                    </Tab.Pane>
                    <Tab.Pane eventKey="product-certification">
                    {product.product_certification.map((certificate) => (
                        <div>
                          <div className="h6 mt-3 mb-3">{certificate.certification_information}</div>
                          <img src={window.location.origin + certificate.image} alt="certificate" height="250px" />
                        </div>
                      ))}
                    </Tab.Pane>
                  </Tab.Content>
                </Col>
              </Row>
            </Tab.Container>
          </div>
        </div>
      </Card.Body>
    </Card> 
  );
}

export default TraceCode;

